@@ -8,7 +8,7 @@ urlpatterns = [
             template_name='robots/robots.txt',
             content_type='text/plain',
             ),
-        name='views.robots.txt'
+        name='robots.views.robotstxt'
         ),
 
     ]
